#!/bin/sh
# Update the main application


directory="/opt/pel/bin"
lib_dir="/opt/pel/lib"
boot_dir="/boot"
mod_dir="/lib/modules"
settings_dir="/etc/qtopia/Scanprobe"
admin_settings="/Settings/Scanprobe/PipeUI.conf"
pel_dir="/opt/pel"
upgradedir="/opt/pel/upgrade"
rulesdir="/etc/udev/rules.d/"
SCRIPT=$(readlink -f "$0")
DIR=$(dirname "$SCRIPT")
supplier=""
module=""

echo $DIR

if [ -f $DIR/SPARTAN ]
then
	echo "supplier set to Spartan" 
	if [ -d $DIR/Explorer ]
	then
		supplier="/Explorer"
		module="3.0.35-pe1588-v1.8.3+.tar.bz2"
	else
		echo "No Explorer folder found" 
		exit 0 
	fi
else
	echo "supplier set to Scanprobe" 
	if [ -d $DIR/Maxprobe ]
	then
		supplier="/Maxprobe"
		module="3.0.35-pe1588-v1.6.5+.tar.bz2"
	else
		echo "No Maxprobe folder found" 
		exit 0 
	fi
fi

# get language
if [ -f $directory/upgrade_language.txt ]
then
	echo "Language File Found!"
	language=$(cat $directory/upgrade_language.txt)
else
	language="en-GB"
fi

echo "$language"	
# Kill PipeUI
echo "killing PipeUI"
killall PipeUI
echo "Waiting 10 seconds to complete"
sleep 10
/bin/dd if=$DIR/pics/updating_$language.fb of=/dev/fb0
echo "Finished waiting"
sleep 1

rm -rf /home/root/scanprobe
zerofiles=$(find -size 0 -type f | wc -l) #check number of files with size 0bytes

if [ ! -s $DIR/PipeUI ]; then
	echo "File isn't executable"
	/bin/dd if=$DIR/pics/failed_$language.fb of=/dev/fb0
elif [ $zerofiles > 0]; then
	echo "Upgrade folder corrupted"
	/bin/dd if=$DIR/pics/failed_$language.fb of=/dev/fb0
else
	# Rename the application for copying
	#mv $DIR/PipeUI $DIR/PipeUI.new
	#echo $?

	# Copy new executable to the bin directory
	echo "Copying new application"
	cp $DIR/PipeUI $directory/PipeUI.new
	echo $?

	sleep 1

	# Remove old application
	echo "Removing old application"
	rm -rf $directory/PipeUI
	echo $?

	# Rename new application to match required name
	echo "Renaming the new application"
	mv $directory/PipeUI.new $directory/PipeUI
	echo $?

	sleep 1

	echo "New application successfully copied"
	echo "Setting Permissions"

	chmod +x $directory/PipeUI
	echo $?

	echo "Removing Superfluous Files"
	rm -rf $directory/PipeUI.new
	#mv $DIR/PipeUI.new $DIR/PipeUI
	echo $?

	if [ -s $DIR/libQtStreamLib.so.1.0.0 ]; then
		echo "Updating Video Library"
		/bin/dd if=$DIR/pics/updating_$language.fb of=/dev/fb0

		#mv $DIR/libQtStreamLib.so.1.0.0 $DIR/libQtStreamLib.so.1.0.0.new
	
		echo "Copying new library"
		cp $DIR/libQtStreamLib.so.1.0.0 $lib_dir/libQtStreamLib.so.1.0.0.new

		sleep 1

		echo "Removing old library"
		rm -rf $lib_dir/libQtStreamLib.so.1.0.0

		echo "Renaming new library"
		mv $lib_dir/libQtStreamLib.so.1.0.0.new $lib_dir/libQtStreamLib.so.1.0.0

		sleep 1

		echo "New library successfully copied"
		echo "Setting Permissions"

		chmod +x $lib_dir/libQtStreamLib.so.1.0.0
		chmod +w $lib_dir/libQtStreamLib.so.1.0.0

		#echo "Removing superfluous files"
		rm -rf $lib_dir/libQtStreamLib.so.1.0.0.new
		#mv $DIR/libQtStreamLib.so.1.0.0.new $DIR/libQtStreamLib.so.1.0.0
	else
		echo "No new library file"
	fi

	if [ -s $DIR/libWCCat.so.1.0.0 ]; then
		echo "Updating WinCan Library"
		/bin/dd if=$DIR/pics/updating_$language.fb of=/dev/fb0

		mv $DIR/libWCCat.so.1.0.0 $DIR/libWCCat.so.1.0.0.new
	
		echo "Copying new library"
		cp $DIR/libWCCat.so.1.0.0.new $lib_dir

		sleep 1

		echo "Removing old library"
		rm -rf $lib_dir/libWCCat.so.1.0.0

		echo "Renaming new library"
		mv $lib_dir/libWCCat.so.1.0.0.new $lib_dir/libWCCat.so.1.0.0

		sleep 1

		echo "New library successfully copied"
		echo "Setting Permissions"

		chmod +x $lib_dir/libWCCat.so.1.0.0
		chmod +w $lib_dir/libWCCat.so.1.0.0

		echo "Removing superfluous files"
		rm -rf $lib_dir/libWCCat.so.1.0.0.new
		mv $DIR/libWCCat.so.1.0.0.new $DIR/libWCCat.so.1.0.0

		echo "Creating Simlinks"
		ln -sf $lib_dir/libWCCat.so.1.0.0 $lib_dir/libWCCat.so.1.0
		ln -sf $lib_dir/libWCCat.so.1.0.0 $lib_dir/libWCCat.so.1
		ln -sf $lib_dir/libWCCat.so.1.0.0 $lib_dir/libWCCat.so
	else
		echo "No new library file"
	fi

	if [ -s $DIR/libPTWinCanWeb.so.1.0.0 ]; then
		echo "Updating WinCanWeb Library"
		/bin/dd if=$DIR/pics/updating_$language.fb of=/dev/fb0

		mv $DIR/libPTWinCanWeb.so.1.0.0 $DIR/libPTWinCanWeb.so.1.0.0.new
	
		echo "Copying new library"
		cp $DIR/libPTWinCanWeb.so.1.0.0.new $lib_dir

		sleep 1

		echo "Removing old library"
		rm -rf $lib_dir/libPTWinCanWeb.so.1.0.0

		echo "Renaming new library"
		mv $lib_dir/libPTWinCanWeb.so.1.0.0.new $lib_dir/libPTWinCanWeb.so.1.0.0

		sleep 1

		echo "New library successfully copied"
		echo "Setting Permissions"

		chmod +x $lib_dir/libPTWinCanWeb.so.1.0.0
		chmod +w $lib_dir/libPTWinCanWeb.so.1.0.0

		echo "Removing superfluous files"
		rm -rf $lib_dir/libPTWinCanWeb.so.1.0.0.new
		mv $DIR/libPTWinCanWeb.so.1.0.0.new $DIR/libPTWinCanWeb.so.1.0.0

		echo "Creating Simlinks"
		ln -sf $lib_dir/libPTWinCanWeb.so.1.0.0 $lib_dir/libPTWinCanWeb.so.1.0
		ln -sf $lib_dir/libPTWinCanWeb.so.1.0.0 $lib_dir/libPTWinCanWeb.so.1
		ln -sf $lib_dir/libPTWinCanWeb.so.1.0.0 $lib_dir/libPTWinCanWeb.so
	else
		echo "No new library file"
	fi
	
	if [ -s $DIR/libvideosystem.so.1.0 ]; then
		echo "Updating Video System Library"
		/bin/dd if=$DIR/pics/updating_$language.fb of=/dev/fb0

		#mv $DIR/libvideosystem.so.1.0 $DIR/libvideosystem.so.1.0.new
	
		echo "Copying new library"
		cp $DIR/libvideosystem.so.1.0 $lib_dir/libvideosystem.so.1.0.new

		sleep 1

		echo "Removing old library"
		rm -rf $lib_dir/libvideosystem.so.1.0

		echo "Renaming new library"
		mv $lib_dir/libvideosystem.so.1.0.new $lib_dir/libvideosystem.so.1.0

		sleep 1

		echo "New library successfully copied"
		echo "Setting Permissions"

		chmod +x $lib_dir/libvideosystem.so.1.0
		chmod +w $lib_dir/libvideosystem.so.1.0

		#echo "Removing superfluous files"
		rm -rf $lib_dir/libvideosystem.so.1.0.new
		#mv $DIR/libvideosystem.so.1.0.new $DIR/libvideosystem.so.1.0
		
		echo "Creating Simlinks"
		ln -sf $lib_dir/libvideosystem.so.1.0 $lib_dir/libvideosystem.so.1
		ln -sf $lib_dir/libvideosystem.so.1.0 $lib_dir/libvideosystem.so
		
	else
		echo "No new vidsys library file"
	fi
	if [ -d $DIR/lib ]; then
		echo "Updating imobiledevice libs"
		cp $DIR/lib/* /usr/local/lib/
	else
		echo "No imobiledevice libs"
	fi
	
	if [ -d $DIR/include ]; then
		echo "Updating imobiledevice libs"
		cp $DIR/include/* /usr/local/include/
		cp -r $DIR/include/plist /usr/local/include/
		cp -r $DIR/include/libusb-1.0 /usr/local/include/
		cp -r $DIR/include/libimobiledevice /usr/local/include/
	else
		echo "No imobiledevice includes"
	fi
	
	if [ -d $DIR/bin ]; then
		echo "Updating imobiledevice binaries"
		cp $DIR/bin/* /usr/bin/
		chmod +x /usr/bin/idevice*
	else
		echo "No imobiledevice binaries"
	fi
	
	if [ -d $DIR/sbin ]; then
		echo "Updating usbmuxd"
		cp $DIR/sbin/usbmuxd /usr/sbin/usbmuxd
		chmod +x /usr/sbin/usbmuxd
	else
		echo "No usbmuxd"
	fi
	
	if [ -s $DIR/$supplier/uImage ]; then
		echo "Updating uImage"
		/bin/dd if=$DIR/pics/updating_$language.fb of=/dev/fb0

		mv $DIR/$supplier/uImage $DIR/uImage.new
	
		echo "Copying new uImage"
		cp $DIR/uImage.new $boot_dir

		sleep 1

		echo "Removing old uImage"
		rm -rf $boot_dir/uImage-pe1588-v1.4
		rm -rf $boot_dir/uImage

		echo "Creating new link"
		mv $boot_dir/uImage.new $boot_dir/uImage
		#ln -s $boot_dir/uImage-pe1588-v1.4 $boot_dir/uImage

		sleep 1

		echo "New library successfully copied"

		echo "Removing superfluous files"
		rm -rf $boot_dir/uImage.new
		mv $DIR/uImage.new $DIR/$supplier/uImage
	else
		echo "No new uImage file"
	fi

	if [ -s $DIR/PE1589/install.sh ]; then
		echo "Updating filesystem"
		/bin/dd if=$DIR/pics/updating_$language.fb of=/dev/fb0

		/bin/sh $DIR/PE1589/install.sh

		echo "Updating filesystem complete!"
	else
		echo "No new file system"
	fi

	if [ -s $DIR/PE1618/install.sh ]; then
		echo "Updating help files"
		/bin/dd if=$DIR/pics/updating_$language.fb of=/dev/fb0

		/bin/sh $DIR/PE1618/install.sh

		echo "Updating help files complete!"
	else
		echo "No new help files"
	fi
	
	if [ -s $DIR/PE1808/install.sh ]; then
		echo "Updating Wifi libraries"
		/bin/dd if=$DIR/pics/updating_$language.fb of=/dev/fb0

		/bin/sh $DIR/PE1808/install.sh

		echo "Updating Wifi libraries complete!"
	else
		echo "No new Wifi libraries"
	fi

	if [ -d $DIR/WinCan ]; then
		echo "Copying Catalogues"
		/bin/dd if=$DIR/pics/updating_$language.fb of=/dev/fb0

		if [ ! -d /opt/pel/etc ]; then
			mkdir /opt/pel/etc
		fi
		
		cp -r $DIR/WinCan /opt/pel/etc/

		echo "Updating Catalogues Complete"
	else
		echo "No new catalogues!"
	fi
	
	if [ -s $DIR/splash.png ]; then
		echo "Updating splash file"
		/bin/dd if=$DIR/pics/updating_$language.fb of=/dev/fb0

		/bin/sh $DIR/makesplash.sh

		mv $DIR/splash.png $DIR/splash.png.new
		mv $DIR/splash.fb $DIR/splash.fb.new
	
		echo "Copying new splash file"
		cp $DIR/splash.png.new $pel_dir
		cp $DIR/splash.fb.new $pel_dir

		sleep 1

		echo "Removing splash file"
		rm -rf $pel_dir/splash.png
		rm -rf $pel_dir/splash.fb

		echo "Renaming new splash file"
		mv $pel_dir/splash.png.new $pel_dir/splash.png
		mv $pel_dir/splash.fb.new $pel_dir/splash.fb
		#ln -s $boot_dir/uImage-pe1588-v1.4 $boot_dir/uImage

		sleep 1

		echo "New splash file copied"

		echo "Removing superfluous files"
		rm -rf $pel_dir/splash.png.new
		rm -rf $pel_dir/splash.fb.new
		mv $DIR/splash.png.new $DIR/splash.png
	else
		echo "No new splash file"
	fi

	if [ -s $DIR/$supplier/$module ]; then
		echo "Updating Modules"
		/bin/dd if=$DIR/pics/updating_$language.fb of=/dev/fb0

		sleep 1

		echo "Removing old modules"
		rm -rf $mod_dir/3.0.35-pe1588*
		rm -rf $mod_dir/3.0.35pe1588*
		
		echo "Unpacking tarball"
		tar -xjf $DIR/$supplier/$module -C $mod_dir

		echo "Modules Updated"

	else
		echo "No new Modules file"
	fi	

	echo "Removing Unwanted WinCan Entries"
	/usr/bin/awk '!/PCDSoilType/' $admin_settings > /Settings/Scanprobe/temp
	mv /Settings/Scanprobe/temp $admin_settings
	rm -rf /Settings/Scanprobe/temp
	
	/usr/bin/awk '!/PCDFlow/' $admin_settings > /Settings/Scanprobe/temp
	mv /Settings/Scanprobe/temp $admin_settings
	rm -rf /Settings/Scanprobe/temp
	echo "Removed Unwanted WinCan Entries"
	
	/usr/bin/awk '!/PipeUI_UK/' $admin_settings > /Settings/Scanprobe/temp
	mv /Settings/Scanprobe/temp $admin_settings
	rm -rf /Settings/Scanprobe/temp
	
	/usr/bin/awk '!/PipeUI_US/' $admin_settings > /Settings/Scanprobe/temp
	mv /Settings/Scanprobe/temp $admin_settings
	rm -rf /Settings/Scanprobe/temp
	echo "Removed Invalid Language Settings"

	chmod 777 $admin_settings

	echo "Done"
	/bin/dd if=$DIR/pics/success_$language.fb of=/dev/fb0
fi

echo Moving MP_HoldOn
cp /opt/pel/bin/mp_holdon.sh /etc/init.d/
/usr/sbin/update-rc.d mp_holdon.sh defaults

/bin/sh $DIR/PE1589/clear_cache.sh

syncfs $DIR

sync

echo "Press Power Button To Reboot System!"

